==> foundation-0.0.52.tgz: package/Default/Builder/Builder.js <==
import { VoxelConstructors } from "./Constructors/Voxel/VoxelConstructors.js";
import { ChunkProcessor } from "./Processors/ChunkProcessor.js";
import { OverrideManager } from "./Rules/Overrides/OverridesManager.js";
import { RenderedSubstances } from "./Rules/RenderedSubstances.js";
import { TextureRegister } from "../../Textures/TextureRegister.js";
import { NodeBuilderManager } from "./Nodes/NodeBuilderManager.js";
import { DivineVoxelEngineConstructor } from "@divinevoxel/core/Contexts/Constructor/DivineVoxelEngineConstructor.js";
import { DVEBuilder } from "../../Interfaces/Builder/DVEBuilder.js";
import { SubstanceRules } from "./Rules/SubstanceRules.js";
export class DVEDefaultBuilder extends DVEBuilder {
    static instance;
    static get defaults() {
        return VoxelConstructors.defaults;
    }
    constructors = VoxelConstructors;
    textureManager = TextureRegister;
    chunkProcessor = new ChunkProcessor();
    nodes = NodeBuilderManager;
    overrides = OverrideManager;
    renderedSubstances = RenderedSubstances;
    constructor(data) {
        super();
        if (!DVEDefaultBuilder.instance)
            DVEDefaultBuilder.instance = this;
        this.constructors.registerVoxel(data.constructors);
        return DVEDefaultBuilder.instance;
    }
    init() {
        DivineVoxelEngineConstructor.instance.TC.registerTasks("sync-texuture-index", (data) => {
            this.textureManager.setTextureIndex(data);
            this.constructors.constructors._map.forEach((_) => {
                _.onTexturesRegistered(this.textureManager);
            });
            this.observers.texturesRegistered.notify(this.textureManager);
            this.textureManager.releaseTextureData();
            SubstanceRules.$BuildRules();
        });
        DivineVoxelEngineConstructor.instance.TC.registerTasks("build-node-mesh", (data, onDone) => {
            const nodeData = this.nodes.buildNode(data);
            if (!nodeData)
                return onDone ? onDone(false) : 0;
            onDone ? onDone(nodeData[0], nodeData[1]) : 0;
        }, "deferred");
    }
    buildChunk(location, LOD = 1) {
        this.chunkProcessor.build(location);
        return true;
    }
}

==> foundation-0.0.53.tgz: package/Default/Builder/Builder.js <==
import { VoxelConstructors } from "./Constructors/Voxel/VoxelConstructors.js";
import { ChunkProcessor } from "./Processors/ChunkProcessor.js";
import { OverrideManager } from "./Rules/Overrides/OverridesManager.js";
import { RenderedSubstances } from "./Rules/RenderedSubstances.js";
import { TextureRegister } from "../../Textures/TextureRegister.js";
import { MesherManager } from "./Meshers/MesherManager.js";
import { DivineVoxelEngineConstructor } from "@divinevoxel/core/Contexts/Constructor/DivineVoxelEngineConstructor.js";
import { DVEBuilder } from "../../Interfaces/Builder/DVEBuilder.js";
import { SubstanceRules } from "./Rules/SubstanceRules.js";
import { VoxelShapeManager } from "./Shapes/VoxelShapeManager.js";
export class DVEDefaultBuilder extends DVEBuilder {
    static instance;
    static get defaults() {
        return VoxelConstructors.defaults;
    }
    constructors = VoxelConstructors;
    textureManager = TextureRegister;
    chunkProcessor = new ChunkProcessor();
    nodes = MesherManager;
    overrides = OverrideManager;
    renderedSubstances = RenderedSubstances;
    shapes = VoxelShapeManager;
    observers = DVEBuilder.observers;
    constructor(data) {
        super();
        if (!DVEDefaultBuilder.instance)
            DVEDefaultBuilder.instance = this;
        this.constructors.registerVoxel(data.constructors);
        return DVEDefaultBuilder.instance;
    }
    init() {
        this.shapes.init();
        DivineVoxelEngineConstructor.instance.TC.registerTasks("sync-texuture-index", (data) => {
            this.textureManager.setTextureIndex(data);
            this.constructors.constructors._map.forEach((_) => {
                _.onTexturesRegistered(this.textureManager);
            });
            this.observers.texturesRegistered.notify(this.textureManager);
            this.textureManager.releaseTextureData();
            SubstanceRules.$BuildRules();
        });
        DivineVoxelEngineConstructor.instance.TC.registerTasks("build-node-mesh", (data, onDone) => {
            const nodeData = this.nodes.buildNode(data);
            if (!nodeData)
                return onDone ? onDone(false) : 0;
            onDone ? onDone(nodeData[0], nodeData[1]) : 0;
        }, "deferred");
    }
    buildChunk(location, LOD = 1, priority = 0) {
        this.chunkProcessor.build(location);
        return true;
    }
}
